import os
import requests

class NurmoAI:
    def __init__(self, api_key=None):
        self.api_key = api_key if api_key is not None else os.environ.get('NURMO_KEY')
        self.base_url = 'https://api.nurmo.app/chat/completions'

    def create_completion(self, messages, model, character=None):
        headers = {'Authorization': self.api_key}

        if character is None:
            raise ValueError("Please provide a character name.")

        data = {'model': model, 'messages': messages, character: character}

        response = requests.post(self.base_url, json=data, headers=headers)
        response_text = response.text

        try:
            response_data = response.json()
            if 'error' in response_data:
                if response_data['error'] == "Unknown model":
                    raise Exception(f"Unknown model named {model}")
                else:
                    raise Exception(response_data['error'])
        except:
            pass

        return response_text



from setuptools import setup, find_packages

setup(
    name='nurmoai',
    version='0.1.0',
    author='Reksely',
    author_email='reksely@gmail.com',
    packages=find_packages(),
    install_requires=[
        'requests>=2.25.1',
    ],
    description='A Python client for the NurmoAI API.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://nurmo.app',
)